var nbsp = 160;    // non-breaking space char
var node_text = 3; // DOM text node-type
var emptyString = /^\s*$/
var glb_vfld;      // retain vfld for timer thread

// -----------------------------------------
//                  trim
// Trim leading/trailing whitespace off string
// -----------------------------------------

function trim(str)
{
  return str.replace(/^\s+|\s+$/g, '')
};


// -----------------------------------------
//                  setfocus
// Delayed focus setting to get around IE bug
// -----------------------------------------

function setFocusDelayed()
{
  glb_vfld.focus()
}

function setfocus(vfld)
{
  // save vfld in global variable so value retained when routine exits
  glb_vfld = vfld;
  setTimeout( 'setFocusDelayed()', 100 );
}


// -----------------------------------------
//                  msg
// Display warn/error message in HTML element
// commonCheck routine must have previously been called
// -----------------------------------------

function msg(fld,     // id of element to display message in
             msgtype, // class to give element ("warn" or "error")
             message) // string to display
{
  // setting an empty string can give problems if later set to a 
  // non-empty string, so ensure a space present. (For Mozilla and Opera one could 
  // simply use a space, but IE demands something more, like a non-breaking space.)
  var dispmessage;
  if (emptyString.test(message)) 
    dispmessage = String.fromCharCode(nbsp);    
  else  
    dispmessage = message;

  var elem = document.getElementById(fld);
  elem.firstChild.nodeValue = dispmessage;  
  
  elem.className = msgtype;   // set the CSS class to adjust appearance of message
};

// -----------------------------------------
//            commonCheck
// Common code for all validation routines to:
// (a) check for older / less-equipped browsers
// (b) check if empty fields are required
// Returns true (validation passed), 
//         false (validation failed) or 
//         proceed (don't know yet)
// -----------------------------------------

var proceed = 2;  

function commonCheck    (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
  if (!document.getElementById) 
    return true;  // not available on this browser - leave validation to the server
  var elem = document.getElementById(ifld);
  if (!elem.firstChild)
    return true;  // not available on this browser 
  if (elem.firstChild.nodeType != node_text)
    return true;  // ifld is wrong type of node  

  if (emptyString.test(vfld.value)) {
    if (reqd) {
      msg (ifld, "error", "ERROR: required");  
      setfocus(vfld);
      return false;
    }
    else {
      msg (ifld, "warn", "");   // OK
      return true;  
    }
  }
  return proceed;
}

// -----------------------------------------
//            validatePresent
// Validate if something has been entered
// Returns true if so 
// -----------------------------------------

function validatePresent(vfld,   // element to be validated
                         ifld )  // id of element to receive info/error msg
{
  var stat = commonCheck (vfld, ifld, true);
  if (stat != proceed) return stat;

  msg (ifld, "warn", "");  
  return true;
};

// -----------------------------------------
//               validateEmail
// Validate if e-mail address
// Returns true if so (and also if could not be executed because of old browser)
// -----------------------------------------

function validateEmail  (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  var tfld = trim(vfld.value);  // value of field with whitespace trimmed off
  var email = /^[^@]+@[^@.]+\.[^@]*\w\w$/
  if (!email.test(tfld)) {
    msg (ifld, "error", "ERROR: not a valid e-mail address");
    setfocus(vfld);
    return false;
  }

  var email2 = /^[A-Za-z][\w.-]+@\w[\w.-]+\.[\w.-]*[A-Za-z][A-Za-z]$/
  if (!email2.test(tfld)) 
    msg (ifld, "warn", "Unusual e-mail address - check if correct");
  else
    msg (ifld, "warn", "");
  return true;
};


// -----------------------------------------
//            validateTelnr
// Validate telephone number
// Returns true if so (and also if could not be executed because of old browser)
// Permits spaces, hyphens, brackets and leading +
// -----------------------------------------

function validateTelnr  (vfld,   // element to be validated
                         ifld,   // id of element to receive info/error msg
                         reqd)   // true if required
{
  var stat = commonCheck (vfld, ifld, reqd);
  if (stat != proceed) return stat;

  var tfld = trim(vfld.value);  // value of field with whitespace trimmed off
  var telnr = /^\+?[0-9 ()-]+[0-9]$/
  if (!telnr.test(tfld)) {
    msg (ifld, "error", "ERROR: not a valid telephone number. Characters permitted are digits, space ()- and leading +");
    setfocus(vfld);
    return false;
  }

  var numdigits = 0;
  for (var j=0; j<tfld.length; j++)
    if (tfld.charAt(j)>='0' && tfld.charAt(j)<='9') numdigits++;

  if (numdigits<6) {
    msg (ifld, "error", "ERROR: " + numdigits + " digits - too short");
    setfocus(vfld);
    return false;
  }

  if (numdigits>14)
    msg (ifld, "warn", numdigits + " digits - check if correct");
  else { 
    if (numdigits<10)
      msg (ifld, "warn", "Only " + numdigits + " digits - check if correct");
    else
      msg (ifld, "warn", "");
  }
  return true;
};

function validateEGN(vfld,ifld,reqd)
{
 var stat = commonCheck (vfld, ifld, reqd);
 if (stat != proceed) return stat;
 var tfld = trim(vfld.value); // value of field with whitespace trimmed off
 var egn = /^\+?[0-9 ()-]+[0-9]$/
 if (!egn.test(tfld))
   {
   msg (ifld, "error", "ERROR: not a valid EGN. Characters permitted are digits");
   setfocus(vfld);
   return false;
   }
 if (tfld.length < 10)
   {
   msg(ifld,"error","ERROR : Not Enough Digits");
   setfocus(vfld);
   return false;
   }
 else
   msg (ifld, "warn", "");
 var Teg = new Array(2,4,8,5,10,9,7,3,6);
 var MesG = new Array(1,3,5,7,8,10,12,41,43,45,47,48,50,52);
 var MesM = new Array(4,6,9,11,44,46,49,51,0,0,0,0,0,0);
 var a = 0;
 var b = 0;
 var c = 0;
 var d = 0;
 a = parseInt(tfld.charAt(0))*10 + parseInt(tfld.charAt(1));
 b = parseInt(tfld.charAt(2))*10 + parseInt(tfld.charAt(3));
 c = parseInt(tfld.charAt(4))*10 + parseInt(tfld.charAt(5));
 if (b > 40)
   a += 2000;
 else 
   a += 1900;
 if ((2005 - a) < 7)
   {
   msg(ifld,"error","ERROR : It's Too Young");
   setfocus(vfld);
   return false;
   }
 else
   msg (ifld, "warn", "");
 if ((2005 - a) > 23)
   {
   msg(ifld,"error","ERROR : It's Too Old");
   setfocus(vfld);
   return false;
   }
 else
   msg (ifld, "warn", "");
 if (((b < 1) || (b > 12)) && ((b < 41) || (b > 52)))
   {
   msg(ifld,"error","ERROR : Not Valid Month");
   setfocus(vfld);
   return false;
   }
 else
   msg (ifld, "warn", "");
 if ((b == 2) || (b == 42)) 
   {
   if (((a % 4 == 0) || (a % 400 == 0)) && (a % 100 != 0))
     {
     if (c > 29)
       {
       msg(ifld,"error","ERROR : Not Valid Date");
       setfocus(vfld);
       return false;
       }
     else
       msg (ifld, "warn", "");
     }
   else
     if (c > 28)
       {
       msg(ifld,"error","ERROR : Not Valid Date");
       setfocus(vfld);
       return false;
       }
     else
       msg (ifld, "warn", "");
   };
 var i;
 for (i = 0; i <= 13; i += 1)
   {
   if (MesG[i] == b) d = 1;
   if (MesM[i] == b) d = 2;
   };
 if ((d == 1) && (c > 31))
     {
     msg(ifld,"error","ERROR : Not Valid Date");
     setfocus(vfld);
     return false;
     }
   else
     msg (ifld, "warn", "");
 if ((d == 2) && (c > 30))
   {
   msg(ifld,"error","ERROR : Not Valid Date");
   setfocus(vfld);
   return false;
   }
 else
     msg (ifld, "warn", "");    
 d = 0;
 for (i = 0; i <= 8; i += 1)
   {
   a = parseInt(tfld.charAt(i));
   d += a*Teg[i];
   };
 d = d % 11;
 a = parseInt(tfld.charAt(9));
 if ((d == 10) && (a != 0))
   {
   msg(ifld,"error","ERROR : Not Valid EGN");
   setfocus(vfld);
   return false;
   }
 else
   msg (ifld, "warn", "");
 if (d != a) 
   {
   msg(ifld,"error","ERROR : Not Valid EGN");
   setfocus(vfld);
   return false;
   }
 else;
   msg (ifld, "warn", "");
return true;
};
